@@ -36,22 +36,23 @@ structure(list(ph = c(6.4, 6.33, 6.94, 6.89, 6.82, 6.12, 6.46,
 34.0689, 35.3642, 35.725, 33.9194, 35.2231, 35.1083, 33.6833, 
 34.4583, 33.6644, 34.5333, 35.095, 33.9872, 37.0625, 34.2639, 
 37.0417, 34.1917, 34.1964, 35.0125, 36.1783, 36.3278, 35.2681
-), lon = c(83.9667, 83.9292, 84.1139, 82.6555, 82.5625, 82.9278, 
-82.9417, 83.1008, 83.0792, 83.0208, 83.0042, 80.1103, 80.93, 
-80.9819, 81.6722, 83.9078, 83.0458, 83.7917, 83.6544, 83.6667, 
-84.2583, 84.6164, 84.6511, 84.3994, 84.0755, 83.555, 83.4289, 
-84.6344, 83.8247, 83.8203, 84.3717, 84.3678, 84.2881, 84.298, 
-84.0769, 82.2025, 82.2042, 83.0958, 83.0617, 83, 82.5181, 82.4167, 
-83.2208, 82.9378, 82.6972, 82.5467, 83.103, 83.3386, 83.3594, 
-83.2825, 83.1911, 83.4969, 83.15, 84.1667, 84.2667, 84.2792, 
-84.3972, 83.7978, 83.1611, 83.875, 82.6653, 83.9736, 81.7333, 
-82.4944, 79.2708, 81.9, 82.3389, 82.2347, 81.743, 82.3936, 83.4292, 
-84.0814, 83.7433, 83.3555, 83.8028, 83.275, 84.1375, 84.0542, 
-82.6972, 84.3, 83.3944, 84.2425, 82.8292, 84.19, 82.8417, 81.4583, 
-84.2917, 82.118, 83.0847, 84.2258, 84.3306, 83.5208, 81.8792, 
-82.0833, 84.1436, 81.7292, 82.05, 84.0458, 82.2083, 84.0417, 
-82.3833, 81.7389, 83.6805, 80.6083, 84.1625, 79.5833, 84, 84.315, 
-83.7875, 82.1564, 82.0833, 82.9694), geog = structure(c(-0.0285729739177452, 
+), lon = c(-83.9667, -83.9292, -84.1139, -82.6555, -82.5625, 
+-82.9278, -82.9417, -83.1008, -83.0792, -83.0208, -83.0042, -80.1103, 
+-80.93, -80.9819, -81.6722, -83.9078, -83.0458, -83.7917, -83.6544, 
+-83.6667, -84.2583, -84.6164, -84.6511, -84.3994, -84.0755, -83.555, 
+-83.4289, -84.6344, -83.8247, -83.8203, -84.3717, -84.3678, -84.2881, 
+-84.298, -84.0769, -82.2025, -82.2042, -83.0958, -83.0617, -83, 
+-82.5181, -82.4167, -83.2208, -82.9378, -82.6972, -82.5467, -83.103, 
+-83.3386, -83.3594, -83.2825, -83.1911, -83.4969, -83.15, -84.1667, 
+-84.2667, -84.2792, -84.3972, -83.7978, -83.1611, -83.875, -82.6653, 
+-83.9736, -81.7333, -82.4944, -79.2708, -81.9, -82.3389, -82.2347, 
+-81.743, -82.3936, -83.4292, -84.0814, -83.7433, -83.3555, -83.8028, 
+-83.275, -84.1375, -84.0542, -82.6972, -84.3, -83.3944, -84.2425, 
+-82.8292, -84.19, -82.8417, -81.4583, -84.2917, -82.118, -83.0847, 
+-84.2258, -84.3306, -83.5208, -81.8792, -82.0833, -84.1436, -81.7292, 
+-82.05, -84.0458, -82.2083, -84.0417, -82.3833, -81.7389, -83.6805, 
+-80.6083, -84.1625, -79.5833, -84, -84.315, -83.7875, -82.1564, 
+-82.0833, -82.9694), geog = structure(c(-0.0285729739177452, 
 -0.0280389786604092, -0.0306689628259679, -0.00989601238908527, 
 -0.00857099227253307, -0.0137754514718356, -0.0139734761978876, 
 -0.0162400142900541, -0.0159323077171262, -0.0151003491033841, 
@@ -127,4 +128,4 @@ structure(list(ph = c(6.4, 6.33, 6.94, 6.89, 6.82, 6.12, 6.46,
 -0.0189304555542258, -0.0188484397154081, -0.00460590761060793, 
 0.0157404744679444, 0.0183493618972045, -0.000144862327408782
 ), .Dim = c(112L, 2L), .Dimnames = list(NULL, c("x", "y")), class = "AsIs")), .Names = c("ph", 
-"cal", "lat", "lon", "geog"))
+"cal", "lat", "lon", "geog"), row.names = c(NA, -112L), class = "data.frame")
